# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

"""The spinsys library.

The spinsys library provides tools for interacting with a Spin system.
"""

__version__ = "0.0.1"
