# Copyright 2024 The Spin Authors. All rights reserved.
# Use of this source code is governed by the Apache 2.0
# license that can be found in the LICENSE file.

import uuid

"""
    UUID represents a spin UUID.

    We alias the uuid.UUID type for clarity and simplicity.
    This way, client code need only import and use the API
    of this module.
"""
UUID = uuid.UUID
